@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: xfce-panel-plugin-iface.c 22813 2006-08-17 17:27:26Z jasper $
+/*  $Id: xfce-panel-plugin-iface.c 23200 2006-09-24 08:57:47Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -287,7 +287,8 @@ xfce_panel_plugin_get_type (void)
             NULL,                       /* class_data */
             0,
             0,                          /* n_preallocs */
-            NULL                        /* instance_init */
+            NULL,                        /* instance_init */
+            NULL
         };
         type = g_type_register_static (G_TYPE_INTERFACE, "XfcePanelPlugin", 
                                        &info, 0);
