@@ -1,6 +1,6 @@
 /* vim: set expandtab ts=8 sw=4: */
 
-/*  $Id: panel-app.c 22981 2006-09-01 17:16:45Z pollux $
+/*  $Id: panel-app.c 23341 2006-10-10 20:18:42Z jasper $
  *
  *  Copyright © 2005 Jasper Huijsmans <jasper@xfce.org>
  *
@@ -110,7 +110,7 @@ struct _PanelApp
 
     GList *dialogs;
 
-    guint initialized:1;
+    guint initialized:1; /* also unset before cleanup */
 
     /* check whether monitors in Xinerama are aligned */
     guint xinerama_and_equal_width:1;
@@ -129,6 +129,11 @@ cleanup_panels (void)
     int i;
     GList *l;
 
+    if (!panel_app.initialized)
+        return;
+
+    panel_app.initialized = FALSE;
+
     l = panel_app.dialogs;
     panel_app.dialogs = NULL;
     
@@ -256,7 +261,7 @@ check_signal_state (void)
 }
 
 static gboolean
-set_signal_state (GIOChannel * source, GIOCondition cond, gpointer d)
+set_signal_state (GIOChannel * source, GIOCondition cond, gpointer data)
 {
     GError *error = NULL;
     GIOStatus status;
@@ -776,6 +781,9 @@ panel_app_customize_items (GtkWidget *active_item)
 void 
 panel_app_save (void)
 {
+    if (!panel_app.initialized)
+        return;
+
     if (xfce_allow_panel_customization())
         panel_config_save_panels (panel_app.panel_list);
 }
@@ -790,7 +798,6 @@ panel_app_restart (void)
 void 
 panel_app_quit (void)
 {
-    panel_app_save();
     panel_app.runstate = PANEL_RUN_STATE_QUIT;
     check_signal_state ();
 }
