@@ -151,7 +151,12 @@ add_selected_item (PanelItemsDialog *pid)
     GtkWidget *item = NULL;
 
     sel = gtk_tree_view_get_selection (GTK_TREE_VIEW (pid->tree));
-    gtk_tree_selection_get_selected (sel, &model, &iter);
+    
+    if (!sel)
+        return FALSE;
+
+    if (!gtk_tree_selection_get_selected (sel, &model, &iter))
+        return FALSE;
 
     gtk_tree_model_get (model, &iter, 0, &info, -1);
 
@@ -1377,8 +1382,13 @@ add_appearance_options (GtkBox *box, PanelManagerDialog *pmd)
 
     /* transparency */
     if (G_UNLIKELY (!composite_atom))
+    {
+        char text[16];
+        g_snprintf (text, 16, "_NET_WM_CM_S%d", 
+                    GDK_SCREEN_XNUMBER(gdk_screen_get_default()));
         composite_atom = 
-            XInternAtom (GDK_DISPLAY (), "COMPOSITING_MANAGER", False);
+            XInternAtom (GDK_DISPLAY (), text, False);
+    }
 
     if (XGetSelectionOwner (GDK_DISPLAY (), composite_atom))
     {
